function params = DefaultParams(SNR)
    % Creates the parameters structure for the NLM-SBW algorithm.
    % INPUT ARGUMENTS:
    % SNR
    %   The signal-to-noise ratio of the corrupted image.
    % OUTPUT ARGUMENTS:
    % params
    %   See below for parameter descriptions.  
    
    % Denoising parameters.
    params.alg.patchSize = 5; % The NLM patch diameter.
    params.alg.numChebyCoef = 50; % The number of Chebychev coefficients used for approximating the SBW function.
    params.alg.bwCutoff = 0.7; % The SBW function cutoff parameter.
    if SNR == 1
        params.alg.sigma = 0.8;  % The NLM kernel width parameter.
        params.alg.bwOrder = 10; % The SBW function order parameter.
    elseif SNR == 0.75
        params.alg.sigma = 1;
        params.alg.bwOrder = 15;
    elseif SNR == 0.5
        params.alg.sigma = 1.5;
        params.alg.bwOrder = 50;
    else
        error('No parameters available for the given SNR');
    end
end