clear variables
clc
dbstop if error
close all
randn('state',1234);
%% Input
SNR = 0.5;
IMAGE_PATH = 'peppers.bmp';
%% Image preprocessing
image = imread(IMAGE_PATH);
if size(image, 3) == 3
    image = rgb2gray(image);
end
image = double(image);
image = image - min(image(:));
image = image / max(image(:));
[ corrupted noise] = CorruptImage(image, SNR);
stdNoise = std(noise(:));
%% Run the algorithm
tic
denoised = NLMSBW(corrupted, SNR, stdNoise, image);
t = toc;
denoisedPsnr = psnr(denoised * 255, image * 255);
fprintf(1, 'PSNR=%.2fdB\n', denoisedPsnr);
fprintf(1, 'Runtime=%.2f sec\n', t);
%% Display the images
subplot(2, 2, 1);
imshow(image);
title('Clean');
subplot(2, 2, 2);
imshow(corrupted);
title('Corrupted');
subplot(2, 2, 3);
imshow(denoised);
title('Denoised');
subplot(2, 2, 4);
imshow(abs(denoised-image), []);