function [ coefs ] = NRChebychev(bwCutoff, bwOrder, n)
    % This function calculates Chebyshev coefficients.
    %
    % Translated from Numerrical Recipes, Third edition, Section 5.8, pp. 236.
    %
    % INPUT ARGUMENTS:
    % image
    %   bwCutoff = the cutoff parameter (in paper w)
    %   bwOrder = the degree of the filter (in paper d)
    %   n = number of required coefficients (in paper N)
    % OUTPUT ARGUMENTS:
    %   coefs = the array of coefficients
   
a =0;
b =1;
if ~exist('n','var')
    n=50;
end

fks=zeros(n,1);
cjs=zeros(n,1);

bma=0.5*(b-a);
bpa=0.5*(b+a);

y=zeros(n,1);

func = @(x) (x.*( (1 + ((1 - x)/bwCutoff).^(2 * bwOrder)).^(-0.5) )   );


for k=0:n-1 % We evaluate the function at the n points required by (5.8.7).
    y(k+1)=cos(pi*(k+0.5)/n); 
    fks(k+1)=func(y(k+1)*bma+bpa);
end
fac=2.0/n;
for j=0:n-1 % Now evaluate (5.8.7).
    sum=0.0;
    for k=0:n-1
        sum = sum + fks(k+1)*cos(pi*j*(k+0.5)/n);
    end
    cjs(j+1)=fac*sum;
end

coefs=cjs; %output
end

